@@ -2,4 +2,4 @@ from __future__ import annotations
 
 from boost_histogram.accumulators import Mean, Sum, WeightedMean, WeightedSum
 
-__all__ = ("Sum", "Mean", "WeightedSum", "WeightedMean")
+__all__ = ("Mean", "Sum", "WeightedMean", "WeightedSum")
