@@ -2,4 +2,4 @@ from __future__ import annotations
 
 from boost_histogram.axis.transform import AxisTransform, Function, Pow, log, sqrt
 
-__all__ = ("AxisTransform", "Pow", "Function", "sqrt", "log")
+__all__ = ("AxisTransform", "Function", "Pow", "log", "sqrt")
