@@ -1,19 +1,17 @@
 from __future__ import annotations
 
+import fnmatch
 import functools
+import itertools
 import operator
 import typing
 import warnings
+from collections.abc import Generator, Iterator, Mapping, Sequence
 from typing import (
     Any,
     Callable,
-    Generator,
-    Iterator,
-    Mapping,
     Protocol,
-    Sequence,
     SupportsIndex,
-    Tuple,
     Union,
 )
 
@@ -48,8 +46,8 @@ InnerIndexing = Union[
     SupportsIndex, str, Callable[[bh.axis.Axis], int], slice, "ellipsis"
 ]
 IndexingWithMapping = Union[InnerIndexing, Mapping[Union[int, str], InnerIndexing]]
-IndexingExpr = Union[IndexingWithMapping, Tuple[IndexingWithMapping, ...]]
-AxisTypes = Union[AxisProtocol, Tuple[int, float, float]]
+IndexingExpr = Union[IndexingWithMapping, tuple[IndexingWithMapping, ...]]
+AxisTypes = Union[AxisProtocol, tuple[int, float, float]]
 
 
 # Workaround for bug in mplhep
@@ -74,14 +72,52 @@ def process_mistaken_quick_construct(
             yield ax
 
 
+NO_METADATA = object()
+
+
 class BaseHist(bh.Histogram, metaclass=MetaConstructor, family=hist):
     __slots__ = ()
 
+    @typing.overload
     def __init__(
         self,
-        *in_args: AxisTypes | Storage | str,
+        arg: dict[str, Any],
+        /,
+        *,
+        data: np.typing.NDArray[Any] | None = ...,
+        metadata: Any = ...,
+        label: str | None = ...,
+        name: str | None = ...,
+    ) -> None: ...
+
+    @typing.overload
+    def __init__(
+        self,
+        arg: Self | bh.Histogram,
+        /,
+        *,
+        data: np.typing.NDArray[Any] | None = ...,
+        metadata: Any = ...,
+        label: str | None = ...,
+        name: str | None = ...,
+    ) -> None: ...
+
+    @typing.overload
+    def __init__(
+        self,
+        *axes: AxisTypes | Storage | str,
+        storage: Storage = ...,
+        metadata: Any = ...,
+        data: np.typing.NDArray[Any] | None = ...,
+        label: str | None = ...,
+        name: str | None = ...,
+    ) -> None: ...
+
+    def __init__(
+        self,
+        *in_args: Self | bh.Histogram | dict[str, Any] | AxisTypes | Storage | str,
         storage: Storage | str | None = None,
-        metadata: Any = None,
+        metadata: Any = NO_METADATA,
         data: np.typing.NDArray[Any] | None = None,
         label: str | None = None,
         name: str | None = None,
@@ -91,8 +127,6 @@ class BaseHist(bh.Histogram, metaclass=MetaConstructor, family=hist):
         """
         self._hist: Any = None
         self.axes: NamedAxesTuple
-        self.name = name
-        self.label = label
 
         args: tuple[AxisTypes, ...]
 
@@ -117,7 +151,10 @@ class BaseHist(bh.Histogram, metaclass=MetaConstructor, family=hist):
             warnings.warn(msg, stacklevel=2)
             storage = storage()
 
-        super().__init__(*args, storage=storage, metadata=metadata)  # type: ignore[call-overload]
+        if metadata is NO_METADATA:
+            super().__init__(*args, storage=storage)  # type: ignore[call-overload]
+        else:
+            super().__init__(*args, storage=storage, metadata=metadata)  # type: ignore[call-overload]
 
         disallowed_names = {"weight", "sample", "threads"}
         for ax in self.axes:
@@ -140,12 +177,8 @@ class BaseHist(bh.Histogram, metaclass=MetaConstructor, family=hist):
         if data is not None:
             self[...] = data
 
-    # Backport of storage_type from boost-histogram 1.3.2:
-    if not hasattr(bh.Histogram, "storage_type"):
-
-        @property
-        def storage_type(self) -> type[bh.storage.Storage]:
-            return self._storage_type
+        self.name = name
+        self.label = label
 
     def _generate_axes_(self) -> NamedAxesTuple:
         """
@@ -183,6 +216,11 @@ class BaseHist(bh.Histogram, metaclass=MetaConstructor, family=hist):
 
         raise ValueError(f"The axis name {name} could not be found")
 
+    def _to_uhi_(self) -> dict[str, Any]:
+        from .serialization import to_uhi
+
+        return to_uhi(self)
+
     @classmethod
     def from_columns(
         cls,
@@ -196,11 +234,11 @@ class BaseHist(bh.Histogram, metaclass=MetaConstructor, family=hist):
         for ax in axes:
             if isinstance(ax, str):
                 assert ax in data, f"{ax} must be present in data={list(data)}"
-                cats = set(data[ax])  # type: ignore[arg-type]
+                cats = set(data[ax])
                 if all(isinstance(a, str) for a in cats):
-                    axes_list.append(hist.axis.StrCategory(sorted(cats), name=ax))  # type: ignore[arg-type]
+                    axes_list.append(hist.axis.StrCategory(sorted(cats), name=ax))
                 elif all(isinstance(a, int) for a in cats):
-                    axes_list.append(hist.axis.IntCategory(sorted(cats), name=ax))  # type: ignore[arg-type]
+                    axes_list.append(hist.axis.IntCategory(sorted(cats), name=ax))
                 else:
                     raise TypeError(
                         f"{ax} must be all int or strings if axis not given"
@@ -214,7 +252,7 @@ class BaseHist(bh.Histogram, metaclass=MetaConstructor, family=hist):
 
         self = cls(*axes_list, storage=storage)
         data_list = {x.name: data[x.name] for x in axes_list}
-        self.fill(**data_list, weight=weight_arr)  # type: ignore[arg-type]
+        self.fill(**data_list, weight=weight_arr)
         return self
 
     def project(self, *args: int | str) -> Self | float | bh.accumulators.Accumulator:
@@ -312,7 +350,7 @@ class BaseHist(bh.Histogram, metaclass=MetaConstructor, family=hist):
                 )
         # Multiple args: broadcast and flatten!
         else:
-            inputs = (*args, *kwargs.values(), *non_user_kwargs)
+            inputs = (*args, *kwargs.values(), *non_user_kwargs.values())
             broadcast = interop.broadcast_and_flatten(inputs)
             user_args_broadcast = broadcast[: len(args)]
             user_kwargs_broadcast = dict(
@@ -346,11 +384,38 @@ class BaseHist(bh.Histogram, metaclass=MetaConstructor, family=hist):
             # This can only return Self, not float, etc., so we ignore the extra types here
             return self[{axis: [bh.loc(x) for x in sorted_cats]}]  # type: ignore[dict-item, return-value]
 
-    def _loc_shortcut(self, x: Any) -> Any:
+    def _convert_index_wildcards(self, x: Any, ax_id: str | int | None = None) -> Any:
+        """
+        Convert wildcards to available indices before passing to bh.loc
+        """
+
+        if not any(
+            isinstance(x, t) for t in [str, list]
+        ):  # Process only lists and strings
+            return x
+        _x = x if isinstance(x, list) else [x]  # Convert to list if not already
+        if not all(isinstance(n, str) for n in _x):
+            return x
+        if any(any(special in pattern for special in ["*", "?"]) for pattern in _x):
+            available = [n for n in self.axes[ax_id] if isinstance(n, str)]
+            all_matches = []
+            for pattern in _x:
+                all_matches.append(
+                    [k for k in available if fnmatch.fnmatch(k, pattern)]
+                )
+            matches = list(
+                dict.fromkeys(list(itertools.chain.from_iterable(all_matches)))
+            )
+            if len(matches) == 0:
+                raise ValueError(f"No matches found for {x}")
+            return matches
+        return x
+
+    def _loc_shortcut(self, x: Any, ax_id: str | int | None = None) -> Any:
         """
         Convert some specific indices to location.
         """
-
+        x = self._convert_index_wildcards(x, ax_id)
         if isinstance(x, list):
             return [self._loc_shortcut(each) for each in x]
         if isinstance(x, slice):
@@ -382,9 +447,7 @@ class BaseHist(bh.Histogram, metaclass=MetaConstructor, family=hist):
             raise ValueError("The imaginary part should be an integer")
         return bh.rebin(int(x.imag))
 
-    def _index_transform(
-        self, index: list[IndexingExpr] | IndexingExpr
-    ) -> bh.IndexingExpr:
+    def _index_transform(self, index: list[IndexingExpr] | IndexingExpr) -> Any:
         """
         Auxiliary function for __getitem__ and __setitem__.
         """
@@ -393,7 +456,7 @@ class BaseHist(bh.Histogram, metaclass=MetaConstructor, family=hist):
             new_indices = {
                 (
                     self._name_to_index(k) if isinstance(k, str) else k
-                ): self._loc_shortcut(v)
+                ): self._loc_shortcut(v, k)
                 for k, v in index.items()
             }
             if len(new_indices) != len(index):
@@ -405,7 +468,7 @@ class BaseHist(bh.Histogram, metaclass=MetaConstructor, family=hist):
         if not isinstance(index, tuple):
             index = (index,)  # type: ignore[assignment]
 
-        return tuple(self._loc_shortcut(v) for v in index)  # type: ignore[union-attr, union-attr, union-attr, union-attr]
+        return tuple(self._loc_shortcut(v, i) for i, (v) in enumerate(index))  # type: ignore[arg-type]
 
     def __getitem__(  # type: ignore[override]
         self, index: IndexingExpr
@@ -499,10 +562,29 @@ class BaseHist(bh.Histogram, metaclass=MetaConstructor, family=hist):
         *,
         ax: matplotlib.axes.Axes | None = None,
         overlay: str | int | None = None,
+        legend: bool = True,
         **kwargs: Any,
     ) -> Hist1DArtists:
         """
         Plot1d method for BaseHist object.
+
+        Parameters
+        ----------
+        ax : matplotlib.axes.Axes, optional
+            Axes to plot on. If None, uses current axes or creates new ones.
+        overlay : str or int, optional
+            Name or index of the axis to overlay. If None, automatically selects
+            the first discrete axis for multi-dimensional histograms.
+        legend : bool, default True
+            Whether to automatically add a legend when plotting stacked categories.
+            The legend title is set from the axis label if available.
+        **kwargs : Any
+            Additional keyword arguments passed to the underlying plot functions.
+
+        Returns
+        -------
+        Hist1DArtists
+            The matplotlib artists created by the plot.
         """
 
         from hist import plot
@@ -529,7 +611,19 @@ class BaseHist(bh.Histogram, metaclass=MetaConstructor, family=hist):
                 raise ValueError(
                     f"label ``{kwargs['label']}`` not understood for {len(cats)} categories"
                 )
-        return plot.histplot(d1hists, ax=ax, label=cats, **_proc_kw_for_lw(kwargs))
+        artists = plot.histplot(d1hists, ax=ax, label=cats, **_proc_kw_for_lw(kwargs))
+        if legend:
+            # Try to set legend title from axis label if available
+            if ax is None:
+                # Get axis from the first artist (mplhep returns Hist1DArtists tuple)
+                # This will raise an error if artists is empty or doesn't have the expected structure,
+                # which is intended behavior as specified in the requirements
+                ax = artists[0].stairs.axes
+            handles, _ = ax.get_legend_handles_labels()
+            if handles:
+                title = getattr(cat_ax, "label", None)
+                ax.legend(title=title if title else None)
+        return artists
 
     def plot2d(
         self,
