@@ -1,7 +1,7 @@
 from __future__ import annotations
 
-from collections.abc import Sequence
-from typing import Any, Callable, Iterator, Protocol, TypeVar, cast
+from collections.abc import Iterator, Sequence
+from typing import Any, Callable, Protocol, TypeVar, cast
 
 import numpy as np
 
@@ -67,15 +67,22 @@ def destructure(obj: Any) -> dict[str, Any] | None:
     raise TypeError(f"No histogram module found for {obj!r}")
 
 
-def broadcast_and_flatten(args: Sequence[Any]) -> tuple[np.typing.NDArray[Any], ...]:
+def broadcast_and_flatten(
+    args: Sequence[Any],
+) -> tuple[str | np.typing.NDArray[Any], ...]:
     """
     Convert the given histogram-module arrays into a set of consistent 1D NumPy arrays
     for histogram filling. For NumPy this entails broadcasting and flattening.
+
+    This skips passing strings to the backend, they are left inplace.
     """
-    for module in find_histogram_modules(*args):
-        result = module.broadcast_and_flatten(args)
+
+    non_strings = [x for x in args if not isinstance(x, str)]
+    for module in find_histogram_modules(*non_strings):
+        result = module.broadcast_and_flatten(non_strings)
         if result is not NotImplemented:
-            return result
+            it = iter(result)
+            return tuple(next(it) if not isinstance(x, str) else x for x in args)
 
     raise TypeError(f"No histogram module found for {args!r}")
 
@@ -99,7 +106,7 @@ class NumpyHistogramModule:
             try:
                 arrays.append(np.asarray(arg))
             except (TypeError, ValueError):
-                return NotImplemented
+                return NotImplemented  # type: ignore[no-any-return]
 
         return tuple(np.ravel(x) for x in np.broadcast_arrays(*arrays))
 
@@ -126,6 +133,6 @@ else:
                 try:
                     arrays.append(np.asarray(arg))
                 except (TypeError, ValueError):
-                    return NotImplemented
+                    return NotImplemented  # type: ignore[no-any-return]
 
             return tuple(np.ravel(x) for x in np.broadcast_arrays(*arrays))
