@@ -2,7 +2,8 @@ from __future__ import annotations
 
 import inspect
 import sys
-from typing import Any, Callable, Iterable, Literal, NamedTuple, Union
+from collections.abc import Iterable
+from typing import Any, Callable, Literal, NamedTuple, Union
 
 import numpy as np
 
@@ -239,7 +240,7 @@ def plot2d_full(
     side_kwargs = _filter_dict(kwargs, "side_")
 
     # judge whether some arguments left
-    if len(kwargs):
+    if kwargs:
         raise ValueError(f"{set(kwargs)} not needed")
 
     # Plot: plot the 2d-histogram
@@ -460,7 +461,7 @@ def plot_ratio_array(
                 valid_ratios + ratio_uncert[1][valid_ratios_idx],
             ]
         )
-        max_delta = np.amax(np.abs(extrema - central_value))
+        max_delta: float = np.amax(np.abs(extrema - central_value))
         ratio_extrema = np.abs(max_delta + central_value)
 
         _alpha = 2.0
