@@ -70,7 +70,7 @@ def svg_hist_1d(h: hist.BaseHist) -> svg:
     (edges,) = h.axes.edges
     norm_edges = (edges - edges[0]) / (edges[-1] - edges[0])
     density = h.density()
-    max_dens = np.amax(density) or 1
+    max_dens: float = np.amax(density) or 1  # type: ignore[redundant-expr, unreachable]
     norm_vals: np.typing.NDArray[Any] = density / max_dens
 
     arr: np.typing.NDArray[np.float64] = np.empty(
@@ -105,7 +105,7 @@ def svg_hist_1d(h: hist.BaseHist) -> svg:
         upper,
         label,
         bins,
-        viewBox=f"-10 {-height-5} {width+20} {height+20}",
+        viewBox=f"-10 {-height - 5} {width + 20} {height + 20}",
     )
 
 
@@ -121,7 +121,7 @@ def svg_hist_1d_c(h: hist.BaseHist) -> svg:
     (edges,) = h.axes.edges
     norm_edges = (edges - edges[0]) / (edges[-1] - edges[0]) * np.pi * 2
     density = h.density()
-    max_dens = np.amax(density) or 1
+    max_dens = np.amax(density) or 1  # type: ignore[redundant-expr, var-annotated, unreachable]
     norm_vals: np.typing.NDArray[Any] = density / max_dens
 
     arr: np.typing.NDArray[np.float64] = np.empty((2, len(norm_vals) * 2), dtype=float)
@@ -142,7 +142,7 @@ def svg_hist_1d_c(h: hist.BaseHist) -> svg:
         style="fill:none;stroke-width:2;stroke:currentColor",
     )
 
-    return svg(bins, center, viewBox=f"{-width/2} {-height/2} {width} {height}")
+    return svg(bins, center, viewBox=f"{-width / 2} {-height / 2} {width} {height}")
 
 
 def svg_hist_2d(h: hist.BaseHist) -> svg:
@@ -155,7 +155,7 @@ def svg_hist_2d(h: hist.BaseHist) -> svg:
     ey = -(e1 - e1[0]) / (e1[-1] - e1[0]) * height
 
     density = h.density()
-    max_dens = np.amax(density) or 1
+    max_dens = np.amax(density) or 1  # type: ignore[redundant-expr, var-annotated, unreachable]
     norm_vals: np.typing.NDArray[Any] = density / max_dens
 
     boxes = []
@@ -190,8 +190,10 @@ def svg_hist_2d(h: hist.BaseHist) -> svg:
             h.axes[1],
             x=-10,
             y=-height / 2,
-            transform=f"rotate(-90,{-10},{-height/2})",
+            transform=f"rotate(-90,{-10},{-height / 2})",
         ),
     ]
 
-    return svg(*texts, *boxes, viewBox=f"{-20} {-height - 20} {width+40} {height+40}")
+    return svg(
+        *texts, *boxes, viewBox=f"{-20} {-height - 20} {width + 40} {height + 40}"
+    )
