@@ -11,4 +11,4 @@ from boost_histogram.tag import (
     underflow,
 )
 
-__all__ = ("Slicer", "Locator", "at", "loc", "overflow", "underflow", "rebin", "sum")
+__all__ = ("Locator", "Slicer", "at", "loc", "overflow", "rebin", "sum", "underflow")
